# Copyright (C) 2007, 2008, 2009 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Build kdepim debian packages from the kdepim/enterprise4 branch.
"""

import os

import treepkg.util

import recipes.kde.enterprise.generic as generic


class SourcePackager(generic.SourcePackager):

    def update_version_numbers(self, pkgbasedir):
        """Overrides the inherited method to update version numbers in the code
        """
        versionstring = "(enterprise4 %s)" % self.enterprise_version
        failed = []
        for versionfile in ["kaddressbook/kabcore.cpp",
                            "kmail/kmversion.h",
                            "kontact/src/main.cpp",
                            "korganizer/version.h"]:
            if not treepkg.util.replace_in_file(os.path.join(pkgbasedir,
                                                             versionfile),
                                                "\(enterprise4 ([^)]*)\)",
                                                versionstring):
                failed.append(versionfile)
        if failed:
            raise RuntimeError("kdepim: failed to update version numbers in %s"
                               % (", ".join(failed),))


class RevisionPackager(generic.RevisionPackager):

    source_packager_cls = SourcePackager


class PackageTrack(generic.PackageTrack):

    revision_packager_cls = RevisionPackager
